==> duckdb_0.2.1.tar.gz: duckdb/src/duckdb/amalgamation-3.cpp <==
#line 0 "src/execution/physical_plan/plan_cross_product.cpp"
#include "src/execution/physical_plan/plan_cross_product.cpp"

#line 0 "src/execution/physical_plan/plan_delete.cpp"
#include "src/execution/physical_plan/plan_delete.cpp"

#line 0 "src/execution/physical_plan/plan_delim_get.cpp"
#include "src/execution/physical_plan/plan_delim_get.cpp"

#line 0 "src/execution/physical_plan/plan_delim_join.cpp"
#include "src/execution/physical_plan/plan_delim_join.cpp"

#line 0 "src/execution/physical_plan/plan_distinct.cpp"
#include "src/execution/physical_plan/plan_distinct.cpp"

#line 0 "src/execution/physical_plan/plan_empty_result.cpp"
#include "src/execution/physical_plan/plan_empty_result.cpp"

#line 0 "src/execution/physical_plan/plan_execute.cpp"
#include "src/execution/physical_plan/plan_execute.cpp"

#line 0 "src/execution/physical_plan/plan_explain.cpp"
#include "src/execution/physical_plan/plan_explain.cpp"

#line 0 "src/execution/physical_plan/plan_export.cpp"
#include "src/execution/physical_plan/plan_export.cpp"

#line 0 "src/execution/physical_plan/plan_expression_get.cpp"
#include "src/execution/physical_plan/plan_expression_get.cpp"

#line 0 "src/execution/physical_plan/plan_filter.cpp"
#include "src/execution/physical_plan/plan_filter.cpp"

#line 0 "src/execution/physical_plan/plan_get.cpp"
#include "src/execution/physical_plan/plan_get.cpp"

#line 0 "src/execution/physical_plan/plan_index_scan.cpp"
#include "src/execution/physical_plan/plan_index_scan.cpp"

#line 0 "src/execution/physical_plan/plan_insert.cpp"
#include "src/execution/physical_plan/plan_insert.cpp"

#line 0 "src/execution/physical_plan/plan_limit.cpp"
#include "src/execution/physical_plan/plan_limit.cpp"

#line 0 "src/execution/physical_plan/plan_order.cpp"
#include "src/execution/physical_plan/plan_order.cpp"

#line 0 "src/execution/physical_plan/plan_prepare.cpp"
#include "src/execution/physical_plan/plan_prepare.cpp"

#line 0 "src/execution/physical_plan/plan_projection.cpp"
#include "src/execution/physical_plan/plan_projection.cpp"

#line 0 "src/execution/physical_plan/plan_recursive_cte.cpp"
#include "src/execution/physical_plan/plan_recursive_cte.cpp"

#line 0 "src/execution/physical_plan/plan_set_operation.cpp"
#include "src/execution/physical_plan/plan_set_operation.cpp"

#line 0 "src/execution/physical_plan/plan_simple.cpp"
#include "src/execution/physical_plan/plan_simple.cpp"

#line 0 "src/execution/physical_plan/plan_table_function.cpp"
#include "src/execution/physical_plan/plan_table_function.cpp"

#line 0 "src/execution/physical_plan/plan_top_n.cpp"
#include "src/execution/physical_plan/plan_top_n.cpp"

#line 0 "src/execution/physical_plan/plan_unnest.cpp"
#include "src/execution/physical_plan/plan_unnest.cpp"

#line 0 "src/execution/physical_plan/plan_update.cpp"
#include "src/execution/physical_plan/plan_update.cpp"

#line 0 "src/execution/physical_plan/plan_window.cpp"
#include "src/execution/physical_plan/plan_window.cpp"

#line 0 "src/execution/physical_plan_generator.cpp"
#include "src/execution/physical_plan_generator.cpp"

#line 0 "src/execution/window_segment_tree.cpp"
#include "src/execution/window_segment_tree.cpp"

#line 0 "src/function/aggregate/algebraic/avg.cpp"
#include "src/function/aggregate/algebraic/avg.cpp"

#line 0 "src/function/aggregate/algebraic/covar.cpp"
#include "src/function/aggregate/algebraic/covar.cpp"

#line 0 "src/function/aggregate/algebraic/stddev.cpp"
#include "src/function/aggregate/algebraic/stddev.cpp"

#line 0 "src/function/aggregate/algebraic_functions.cpp"
#include "src/function/aggregate/algebraic_functions.cpp"

#line 0 "src/function/aggregate/distributive/bitagg.cpp"
#include "src/function/aggregate/distributive/bitagg.cpp"

#line 0 "src/function/aggregate/distributive/count.cpp"
#include "src/function/aggregate/distributive/count.cpp"

#line 0 "src/function/aggregate/distributive/first.cpp"
#include "src/function/aggregate/distributive/first.cpp"

#line 0 "src/function/aggregate/distributive/minmax.cpp"
#include "src/function/aggregate/distributive/minmax.cpp"

#line 0 "src/function/aggregate/distributive/string_agg.cpp"
#include "src/function/aggregate/distributive/string_agg.cpp"

#line 0 "src/function/aggregate/distributive/sum.cpp"
#include "src/function/aggregate/distributive/sum.cpp"

#line 0 "src/function/aggregate/distributive_functions.cpp"
#include "src/function/aggregate/distributive_functions.cpp"

#line 0 "src/function/aggregate/nested/list.cpp"
#include "src/function/aggregate/nested/list.cpp"

#line 0 "src/function/aggregate/nested_functions.cpp"
#include "src/function/aggregate/nested_functions.cpp"

#line 0 "src/function/cast_rules.cpp"
#include "src/function/cast_rules.cpp"

#line 0 "src/function/function.cpp"
#include "src/function/function.cpp"

#line 0 "src/function/scalar/date/age.cpp"
#include "src/function/scalar/date/age.cpp"

#line 0 "src/function/scalar/date/current.cpp"
#include "src/function/scalar/date/current.cpp"

#line 0 "src/function/scalar/date/date_part.cpp"
#include "src/function/scalar/date/date_part.cpp"

#line 0 "src/function/scalar/date/date_trunc.cpp"
#include "src/function/scalar/date/date_trunc.cpp"

#line 0 "src/function/scalar/date/epoch.cpp"
#include "src/function/scalar/date/epoch.cpp"

#line 0 "src/function/scalar/date/strftime.cpp"
#include "src/function/scalar/date/strftime.cpp"

#line 0 "src/function/scalar/date_functions.cpp"
#include "src/function/scalar/date_functions.cpp"

#line 0 "src/function/scalar/generic/least.cpp"
#include "src/function/scalar/generic/least.cpp"

#line 0 "src/function/scalar/generic_functions.cpp"
#include "src/function/scalar/generic_functions.cpp"

#line 0 "src/function/scalar/math/numeric.cpp"
#include "src/function/scalar/math/numeric.cpp"

#line 0 "src/function/scalar/math/random.cpp"
#include "src/function/scalar/math/random.cpp"

#line 0 "src/function/scalar/math/setseed.cpp"
#include "src/function/scalar/math/setseed.cpp"

#line 0 "src/function/scalar/math_functions.cpp"
#include "src/function/scalar/math_functions.cpp"

#line 0 "src/function/scalar/nested/list_value.cpp"
#include "src/function/scalar/nested/list_value.cpp"

#line 0 "src/function/scalar/nested/struct_extract.cpp"
#include "src/function/scalar/nested/struct_extract.cpp"

#line 0 "src/function/scalar/nested/struct_pack.cpp"
#include "src/function/scalar/nested/struct_pack.cpp"

#line 0 "src/function/scalar/nested_functions.cpp"
#include "src/function/scalar/nested_functions.cpp"

#line 0 "src/function/scalar/operators.cpp"
#include "src/function/scalar/operators.cpp"

#line 0 "src/function/scalar/operators/arithmetic.cpp"
#include "src/function/scalar/operators/arithmetic.cpp"

#line 0 "src/function/scalar/operators/bitwise.cpp"
#include "src/function/scalar/operators/bitwise.cpp"

#line 0 "src/function/scalar/sequence/nextval.cpp"
#include "src/function/scalar/sequence/nextval.cpp"

#line 0 "src/function/scalar/sequence_functions.cpp"
#include "src/function/scalar/sequence_functions.cpp"

#line 0 "src/function/scalar/string/caseconvert.cpp"
#include "src/function/scalar/string/caseconvert.cpp"

#line 0 "src/function/scalar/string/concat.cpp"
#include "src/function/scalar/string/concat.cpp"

#line 0 "src/function/scalar/string/contains.cpp"
#include "src/function/scalar/string/contains.cpp"

#line 0 "src/function/scalar/string/instr.cpp"
#include "src/function/scalar/string/instr.cpp"

#line 0 "src/function/scalar/string/left_right.cpp"
#include "src/function/scalar/string/left_right.cpp"

#line 0 "src/function/scalar/string/length.cpp"
#include "src/function/scalar/string/length.cpp"

#line 0 "src/function/scalar/string/like.cpp"
#include "src/function/scalar/string/like.cpp"

#line 0 "src/function/scalar/string/pad.cpp"
#include "src/function/scalar/string/pad.cpp"

#line 0 "src/function/scalar/string/prefix.cpp"
#include "src/function/scalar/string/prefix.cpp"

#line 0 "src/function/scalar/string/printf.cpp"
#include "src/function/scalar/string/printf.cpp"

==> duckdb_0.2.1-2.tar.gz: duckdb/src/duckdb/amalgamation-3.cpp <==
#include "src/execution/physical_plan/plan_execute.cpp"

#include "src/execution/physical_plan/plan_explain.cpp"

#include "src/execution/physical_plan/plan_export.cpp"

#include "src/execution/physical_plan/plan_expression_get.cpp"

#include "src/execution/physical_plan/plan_filter.cpp"

#include "src/execution/physical_plan/plan_get.cpp"

#include "src/execution/physical_plan/plan_insert.cpp"

#include "src/execution/physical_plan/plan_limit.cpp"

#include "src/execution/physical_plan/plan_order.cpp"

#include "src/execution/physical_plan/plan_pragma.cpp"

#include "src/execution/physical_plan/plan_prepare.cpp"

#include "src/execution/physical_plan/plan_projection.cpp"

#include "src/execution/physical_plan/plan_recursive_cte.cpp"

#include "src/execution/physical_plan/plan_set_operation.cpp"

#include "src/execution/physical_plan/plan_simple.cpp"

#include "src/execution/physical_plan/plan_top_n.cpp"

#include "src/execution/physical_plan/plan_unnest.cpp"

#include "src/execution/physical_plan/plan_update.cpp"

#include "src/execution/physical_plan/plan_window.cpp"

#include "src/execution/physical_plan_generator.cpp"

#include "src/execution/window_segment_tree.cpp"

#include "src/function/aggregate/algebraic/avg.cpp"

#include "src/function/aggregate/algebraic/covar.cpp"

#include "src/function/aggregate/algebraic/stddev.cpp"

#include "src/function/aggregate/algebraic_functions.cpp"

#include "src/function/aggregate/distributive/bitagg.cpp"

#include "src/function/aggregate/distributive/count.cpp"

#include "src/function/aggregate/distributive/first.cpp"

#include "src/function/aggregate/distributive/minmax.cpp"

#include "src/function/aggregate/distributive/string_agg.cpp"

#include "src/function/aggregate/distributive/sum.cpp"

#include "src/function/aggregate/distributive_functions.cpp"

#include "src/function/aggregate/nested/list.cpp"

#include "src/function/aggregate/nested_functions.cpp"

#include "src/function/cast_rules.cpp"

#include "src/function/function.cpp"

#include "src/function/pragma/pragma_functions.cpp"

#include "src/function/pragma/pragma_queries.cpp"

#include "src/function/pragma_function.cpp"

#include "src/function/scalar/date/age.cpp"

#include "src/function/scalar/date/current.cpp"

#include "src/function/scalar/date/date_part.cpp"

#include "src/function/scalar/date/date_trunc.cpp"

#include "src/function/scalar/date/epoch.cpp"

#include "src/function/scalar/date/strftime.cpp"

#include "src/function/scalar/date_functions.cpp"

#include "src/function/scalar/generic/least.cpp"

#include "src/function/scalar/generic_functions.cpp"

#include "src/function/scalar/math/numeric.cpp"

#include "src/function/scalar/math/random.cpp"

#include "src/function/scalar/math/setseed.cpp"

#include "src/function/scalar/math_functions.cpp"

#include "src/function/scalar/nested/list_value.cpp"

#include "src/function/scalar/nested/struct_extract.cpp"

#include "src/function/scalar/nested/struct_pack.cpp"

#include "src/function/scalar/nested_functions.cpp"

#include "src/function/scalar/operators.cpp"

#include "src/function/scalar/operators/arithmetic.cpp"

#include "src/function/scalar/operators/bitwise.cpp"

#include "src/function/scalar/pragma_functions.cpp"

#include "src/function/scalar/sequence/nextval.cpp"

#include "src/function/scalar/sequence_functions.cpp"

#include "src/function/scalar/string/caseconvert.cpp"

#include "src/function/scalar/string/concat.cpp"

#include "src/function/scalar/string/contains.cpp"

#include "src/function/scalar/string/instr.cpp"

#include "src/function/scalar/string/left_right.cpp"

#include "src/function/scalar/string/length.cpp"

#include "src/function/scalar/string/like.cpp"

#include "src/function/scalar/string/nfc_normalize.cpp"

#include "src/function/scalar/string/pad.cpp"

#include "src/function/scalar/string/prefix.cpp"

#include "src/function/scalar/string/printf.cpp"

#include "src/function/scalar/string/regexp.cpp"

#include "src/function/scalar/string/repeat.cpp"

#include "src/function/scalar/string/replace.cpp"

#include "src/function/scalar/string/reverse.cpp"
